function [ Area, I, J ] = Sec_Prop_HCircle( Dia_Out, Dia_In )
%
%  Sec_Prop_Circle
%
%        This routine computes the section properties of a hollow circle
%
%  Input
%    DiaOut     Outside diameter of the circle
%    Dia_In     Inside diameter of the circle
%
%  Output
%    Area    The area of the circle
%    I       The second moment of inertia
%    J       The polar second moment of inertia
%

Area = pi * (Dia_Out ^ 2 - Dia_In ^ 2) / 4;
I = pi * (Dia_Out ^ 4 - Dia_In ^ 4) / 64;
J = 2 * I;

end

